@@ -53,13 +53,6 @@ def create_training_job(local_data, source_code, weights, hyper_param):
             __upload_one_folder(job_id, FileType.Traindata.name, local_data)
             print(f"uploaded {local_data}")
     
-    """
-    if local_data is not None:
-        __upload_one_folder(job_id, FileType.Traindata.name, local_data)
-        print(f"uploaded {local_data}")
-    else:
-        print("Please at s3_position input S3 public datasetes url")
-    """
 
     if source_code is not None:
         __upload_one_file(job_id, FileType.Code.name, source_code)
@@ -79,7 +72,7 @@ def create_training_job(local_data, source_code, weights, hyper_param):
     response = requests.request("POST", f"{API_GW}/job", headers=headers, data=payload)
 
     print(response)
-
+    get_training_job_logstream(job_id)
     return job_id
 
 
@@ -93,11 +86,17 @@ def get_training_job_status(job_id):
 
     # read status from API Gateay - backed by Dynamodb
     url = f"{API_GW}/jobs/{job_id}"
-    print(f"getting {url}")
+    #print(f"getting {url}")
     response = requests.request("GET", url)
-    print(f"response {response}")
+    #print(f"response {response}")
     response_body = json.loads(response.text)
-    print(response_body[job_id])
+    if len(response_body) == 2:
+        return print("waiting...")
+    else:
+        if response_body[job_id] == "InProgress":
+            pass
+        else:
+            print(response_body[job_id])
     return response_body[job_id]
 
 def get_model(job_id, model):
@@ -115,8 +114,37 @@ def get_model(job_id, model):
         tar.close()
 
 
-
-
+def get_training_job_logstream(job_id):
+    url = f"{API_GW}/jobs/{job_id}"
+    #print(f"getting {url}")
+    tmp_status = ["Completed", "Failed", "Stopped"]
+    headers = {
+        'Content-Type': 'application/json'
+    }
+    #print(f"reponse {response}")
+    len_c = 0
+    job_status = get_training_job_status(job_id)
+    #print(job_status)
+    while True:
+        response = requests.request("POST", url, headers=headers)
+        contents = json.loads(response.text)
+        len_cc = len(contents)
+        #print(len_c,len_cc)
+        if len_cc > len_c and len_cc!=2:
+            #len_d = len_cc- len_c
+            contents = contents[len_c:len_cc]
+            len_c = len_cc
+            for content in contents:
+                print(content)
+        elif len_cc == len_c:
+            pass
+        else:
+            print("waiting...")
+        time.sleep(10)
+        job_status = get_training_job_status(job_id)
+        if job_status in tmp_status:
+            break
+    return response
     
 
 def cancel_training_job_status(job_id):
@@ -197,23 +225,23 @@ if __name__ == "__main__":
 
     #make_tar("yolov5") 
     #s3://code-devcloud/jobs/05ec9d2d-8862-49c1-9d1c-a39125e23fc2/Traindata/datasets_simple/
-    """
-    create_training_job("datasets_simple",
+    
+    create_training_job("s3://code-devcloud/jobs/05ec9d2d-8862-49c1-9d1c-a39125e23fc2/Traindata/datasets_simple/",
                         "yolov5.tar",
                         "yolov5s.pt",
                         {"instance_type":"ml.m5.xlarge",
                         "instance_count":"1",
                         "framework_version":"1.8.1",
                         "hyperparameters":{"imgsz":"64", "epochs":"10"}})
-    """
+    
     #make_tar("train.py")
     #s3://code-devcloud/jobs/090e3c81-804a-4a34-abfb-33d67d77bfa8/Traindata/mnist/
-    
-    create_training_job("mnist",
+    """
+    create_training_job("s3://code-devcloud/jobs/090e3c81-804a-4a34-abfb-33d67d77bfa8/Traindata/mnist/",
                         "train.tar",
                         None,
                         {"instance_type":"ml.m5.xlarge",
                         "instance_count":"1",
                         "framework_version":"1.1.0",
                         "hyperparameters":{"epochs":"4","backend":"gloo", "hidden_channels":"2", "dropout":"0.2","kernel_size":"5", "optimizer":"sgd"}})
-    
+    """
